pub enum StartRecommendedErrorType {
Deserializing,
Request,
}👎Deprecated since 0.17.2
Available on crate feature
twilight-http only.Expand description
Type of StartRecommendedError that occurred.
Variants
Deserializing
👎Deprecated since 0.17.2
Received gateway event failed to be deserialized.
The message payload is likely an unrecognized type that is not yet supported.
Request
👎Deprecated since 0.17.2
Requesting recommended shards from Discord’s REST API failed.
May be due to something such as a network or authentication issue.